==> supertokens_python-0.8.4.tar.gz: supertokens_python-0.8.4/supertokens_python/recipe/emailverification/emaildelivery/services/smtp/email_verify.py <==
# Copyright (c) 2021, VRAI Labs and/or its affiliates. All rights reserved.
#
# This software is licensed under the Apache License, Version 2.0 (the
# "License") as published by the Apache Software Foundation.
#
# You may not use this file except in compliance with the License. You may
# obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from string import Template

from supertokens_python.ingredients.emaildelivery.services.smtp import \
    GetContentResult
from supertokens_python.recipe.emailverification.interfaces import \
    TypeEmailVerificationEmailDeliveryInput
from supertokens_python.supertokens import Supertokens

from .email_verify_email import html_template


def get_email_verify_email_content(email_input: TypeEmailVerificationEmailDeliveryInput) -> GetContentResult:
    supertokens = Supertokens.get_instance()
    app_name = supertokens.app_info.app_name
    body = get_email_verify_email_html(app_name, email_input.user.email, email_input.email_verify_link)
    return GetContentResult(body, "Email verification instructions", email_input.user.email, is_html=True)


def get_email_verify_email_html(app_name: str, email: str, verification_link: str):
    return Template(html_template).substitute(appname=app_name, verificationLink=verification_link, toEmail=email)

==> supertokens_python-0.9.1.tar.gz: supertokens_python-0.9.1/supertokens_python/recipe/emailverification/emaildelivery/services/smtp/email_verify.py <==
# Copyright (c) 2021, VRAI Labs and/or its affiliates. All rights reserved.
#
# This software is licensed under the Apache License, Version 2.0 (the
# "License") as published by the Apache Software Foundation.
#
# You may not use this file except in compliance with the License. You may
# obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from string import Template

from supertokens_python.ingredients.emaildelivery.types import EmailContent
from supertokens_python.recipe.emailverification.types import VerificationEmailTemplateVars
from supertokens_python.supertokens import Supertokens

from .email_verify_email import html_template


def get_email_verify_email_content(email_input: VerificationEmailTemplateVars) -> EmailContent:
    supertokens = Supertokens.get_instance()
    app_name = supertokens.app_info.app_name
    body = get_email_verify_email_html(app_name, email_input.user.email, email_input.email_verify_link)
    return EmailContent(body, "Email verification instructions", email_input.user.email, is_html=True)


def get_email_verify_email_html(app_name: str, email: str, verification_link: str):
    return Template(html_template).substitute(appname=app_name, verificationLink=verification_link, toEmail=email)
